package com.fs.company.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.common.core.domain.R;
import com.fs.company.domain.CompanyDomainBind;
import com.fs.company.param.CompanyDomainBindParam;
import com.fs.company.vo.CompanyDomainBindVo;

/**
 * 域名绑定销售公司Service接口
 * 
 * @author fs
 * @date 2025-06-17
 */
public interface ICompanyDomainBindService extends IService<CompanyDomainBind>{
    /**
     * 查询域名绑定销售公司
     * 
     * @param id 域名绑定销售公司主键
     * @return 域名绑定销售公司
     */
    CompanyDomainBind selectCompanyDomainBindById(Long id);

    /**
     * 查询域名绑定销售公司列表
     * 
     * @param companyDomainBind 域名绑定销售公司
     * @return 域名绑定销售公司集合
     */
    List<CompanyDomainBindVo> selectCompanyDomainBindList(CompanyDomainBindParam companyDomainBind);

    /**
     * 新增域名绑定销售公司
     * 
     * @param companyDomainBind 域名绑定销售公司
     * @return 结果
     */
    int insertCompanyDomainBind(CompanyDomainBind companyDomainBind);

    /**
     * 修改域名绑定销售公司
     * 
     * @param companyDomainBind 域名绑定销售公司
     * @return 结果
     */
    int updateCompanyDomainBind(CompanyDomainBind companyDomainBind);

    /**
     * 批量删除域名绑定销售公司
     * 
     * @param ids 需要删除的域名绑定销售公司主键集合
     * @return 结果
     */
    int deleteCompanyDomainBindByIds(Long[] ids);

    /**
     * 删除域名绑定销售公司信息
     * 
     * @param id 域名绑定销售公司主键
     * @return 结果
     */
    int deleteCompanyDomainBindById(Long id);


    /**
     * 域名批量绑定接口
     *
     * @param param 接收参数
     * @return R
     **/
    R domainBatchBinding(CompanyDomainBindParam param);
}
